/*
** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
** distribution information.
*/

#if	HAVE_CONFIG_H
#include	"config.h"
#endif
#include	<string.h>
#if	HAVE_UNISTD_H
#include	<unistd.h>
#endif
#include	"md5/md5.h"
#include	"auth.h"

static const char rcsid[]="$Id: checkpasswordmd5.c,v 1.4 2000/06/29 01:45:10 mrsam Exp $";

int authcheckpasswordmd5(const char *password, const char *encrypted_password)
{
	if (strncmp(encrypted_password, "$1$", 3) == 0)
	{
		return (strcmp(encrypted_password,
			md5_crypt(password, encrypted_password)));
	}

#if 0

	/* NOT UNTIL THIS IS TESTED */

	if (strncmp(encrypted_password, "{MD5}", 5) == 0)
	{
		return (strcmp(encrypted_password, md5_hash(password)));
	}
#endif
	return (-1);
}
